@@ -9,7 +9,6 @@ import aiocoap
 import aiocoap.resource
 from aiocoap.numbers import ContentFormat
 import unittest
-import logging
 import os
 import json
 
@@ -274,13 +273,17 @@ class WithClient(WithAsyncLoop, Destructing):
     def setUp(self):
         super(WithClient, self).setUp()
 
+        self.test_did_shut_down_client = False
+
         self.client = self.loop.run_until_complete(
             aiocoap.Context.create_client_context()
         )
 
     def tearDown(self):
-        self.loop.run_until_complete(asyncio.sleep(CLEANUPTIME))
-        self.loop.run_until_complete(self.client.shutdown())
+        if not self.test_did_shut_down_client:
+            self.test_did_shut_down_client = False
+            self.loop.run_until_complete(asyncio.sleep(CLEANUPTIME))
+            self.loop.run_until_complete(self.client.shutdown())
 
         # Nothing in the context should keep the request interfaces alive;
         # delete them first to see *which* of them is the one causing the
@@ -549,7 +552,7 @@ class TestServer(TestServerBase):
         self.assertEqual(response.code, aiocoap.CONTENT, "Root resource was not found")
 
     _empty_ack_logmsg = re.compile(
-        "^Incoming message <aiocoap.Message at" " 0x[0-9a-f]+: ACK EMPTY ([^)]+)"
+        "^Incoming message <aiocoap.Message at 0x[0-9a-f]+: ACK EMPTY ([^)]+)"
     )
 
     def _count_empty_acks(self):
@@ -561,6 +564,22 @@ class TestServer(TestServerBase):
             if x.name != "coap-server"
         )
 
+    @no_warnings
+    def test_clean_shutdown(self):
+        self.loop.run_until_complete(self.client.shutdown())
+        self.test_did_shut_down_client = True
+
+        request = self.build_request()
+        # This is clearly misuse of the API, but nonetheless, only a
+        # LibraryShutdown should fly out of it.
+        #
+        # Ideally, we'd do that "during" shutdown", but that's terribly racy
+        # business, both wins are acceptable (what if the shutdown hasn't
+        # really begun yet), and it's highly unlikely that we hit the juicy
+        # cases.
+        with self.assertRaises(aiocoap.error.LibraryShutdown):
+            self.loop.run_until_complete(self.fetch_response(request))
+
 
 @unittest.skipIf(common.tcp_disabled, "TCP disabled in environment")
 class TestServerTCP(TestServer):
@@ -591,24 +610,6 @@ class TestServerWS(TestServer):
         return request
 
 
-def run_fixture_as_standalone_server(fixture):
-    import sys
-
-    if "-v" in sys.argv:
-        logging.basicConfig()
-        logging.getLogger("coap").setLevel(logging.DEBUG)
-        logging.getLogger("coap-server").setLevel(logging.DEBUG)
-
-    print("Running test server")
-    s = fixture()
-    s.setUp()
-    try:
-        s.loop.run_forever()
-    except KeyboardInterrupt:
-        print("Shutting down test server")
-        s.tearDown()
-
-
 if __name__ == "__main__":
     # due to the imports, you'll need to run this as `python3 -m tests.test_server`
-    run_fixture_as_standalone_server(WithTestServer)
+    common.run_fixture_as_standalone_server(WithTestServer)
